==> haskell-crypto-random-0.0.9-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-random
version: 0.0.9
id: crypto-random-0.0.9-3hO7lgyx579EdJGw5NW2lQ
key: crypto-random-0.0.9-3hO7lgyx579EdJGw5NW2lQ
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-random
synopsis: Simple cryptographic random related types
description:
    Simple cryptographic random related types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules: Crypto.Random.Generator Crypto.Random.Entropy
                Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
                Crypto.Random.Entropy.RDRand
abi: 9d4ea03715db87adcef790518589e9d6
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/crypto-random-0.0.9
library-dirs: /usr/lib/ghc-8.2.1/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/crypto-random-0.0.9
hs-libraries: HScrypto-random-0.0.9-3hO7lgyx579EdJGw5NW2lQ
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    securemem-0.1.9-IkOuAib5iR08lq4Le9fClQ unix-2.7.2.2
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             securemem-0.1.9-IkOuAib5iR08lq4Le9fClQ=a4d58e5f02e1b3671ba392c2e4813e4f
             unix-2.7.2.2=65f42a53c0d1c7bb4ba5966ba6a43504
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
haddock-interfaces: /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock
haddock-html: /usr/share/doc/haskell-crypto-random/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-random-0.0.9-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-random
version: 0.0.9
id: crypto-random-0.0.9-BSpM7y7ISpuFpciKyVdNkw
key: crypto-random-0.0.9-BSpM7y7ISpuFpciKyVdNkw
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-random
synopsis: Simple cryptographic random related types
description:
    Simple cryptographic random related types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules: Crypto.Random.Generator Crypto.Random.Entropy
                Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
                Crypto.Random.Entropy.RDRand
abi: 3b7d177dc80b8bc5e1bfdcce1f18012a
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/crypto-random-0.0.9
library-dirs: /usr/lib/ghc-8.2.1/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/crypto-random-0.0.9
hs-libraries: HScrypto-random-0.0.9-BSpM7y7ISpuFpciKyVdNkw
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE unix-2.7.2.2
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             securemem-0.1.9-5GPDBCPv82wLmZFtmA9fPE=2a1bfce820b6c9cd60b466627f1cd95a
             unix-2.7.2.2=65f42a53c0d1c7bb4ba5966ba6a43504
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
haddock-interfaces: /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock
haddock-html: /usr/share/doc/haskell-crypto-random/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
